//AC130-Script by LurchiDerLurch ac130_rot_setup

private ["_plane","_pos","_radius","_height","_sequence"];

_input = _this select 0;
_radius = _this select 1;
_height = _this select 2;
_sequence = _this select 3;

//Below are some options you can set:
//********//
//_radius = 900; //radius for the AC130; default: use the radius from the call argument
//_height = 1000; //start-height for the AC130; default: use the height from the call argument
_aboveSeaLevel = true; // height is above sea level and not above ground, AC130 will not automaticly correct height; default true 
_munition_25mm = 1000; //Munition for the 25mm; default: 2000
_munition_40mm = 50; //Munition for the 40mm; default: 100
_munition_105mm = 20; //Munition for the 105mm; default: 30
_showSignal = true; //Show signal for friendly units; default: true
_enableHud = true; //Show vehicles as a square; default: true
_enableFlir = true; //Flir; default: true
_contrast = 0.1; //Contrast of flir; default: 0.1
_360View = false; //360 view (UAV) or limited on the left side of the aircraft (AC130); default: false
_useNVG = false; //Use night vision googles; default: false
_typeOfNVG = 0; //Which type of night vision googles, 0 = green, 1 = grey; default: 0
_showWaypoints = false; //Show waypoints; default: false
_showParticles = true; //Show particles (smoke, tracer etc.); default: true
_enablePhysics = true; //Enable physics for the plane. Disabling it avoids instability of the rotating plane (takes no affect on camera); default: true
_maxZoom_25mm = 9.5; //Maximum zoom level for 25mm; default: 9.5 (only numbers between 1 and 10)
_maxZoom_40mm = 9; //Maximum zoom level for 40mm; default: 9 (only numbers between 1 and 10)
_maxZoom_105mm = 8; //Maximum zoom level for 105mm; default: 8 (only numbers between 1 and 10)
_endTime = -1; //Time in seconds when AC130 script stops; use the time from the call argument
//********//

waitUntil{(!LDL_ac130_active)};

//put the options in an array
_variables = [_radius,_height,_aboveSeaLevel,_munition_25mm,_munition_40mm,_munition_105mm,_showSignal,_enableHud,_enableFlir,_contrast,_360View,_useNVG,_typeOfNVG,_showWaypoints,_showParticles,_maxZoom_25mm,_maxZoom_40mm,_maxZoom_105mm,_endTime];

_setCirclePosition =
{
	(_this select 0) setPosASL [(getPos LDL_cam_rotating_center select 0)+sin(LDL_cam_rotating_angle)*(_this select 1),(getPos LDL_cam_rotating_center select 1)+cos(LDL_cam_rotating_angle)*(_this select 1), LDL_cam_rotating_height];	
};

LDL_ac130_active = true;
LDL_plane_type = "AC130";

if (typeName _input == "ARRAY") then
{
	_pos = _input;
	LDL_cam_rotating_center setPos _pos;
	LDL_ac130_plane = createVehicle ["C130J",[getPos player select 0,getPos player select 1,1000], [], 0, "FLY"];
	_ac130_pilot = "USMC_Soldier_Pilot" createUnit [getPos player,createGroup WEST,"LDL_ac130_pilot = this; this moveInDriver LDL_ac130_plane;", 0.6, "corporal"];
	
	//delete
	[LDL_ac130_plane]spawn
	{
		_plane = _this select 0;
		waitUntil{sleep 1;(!LDL_ac130_active)};
		deleteVehicle _plane;
		deleteVehicle LDL_ac130_pilot;
	};
	
	_variables call LDL_setVariables;

	[LDL_ac130_plane,LDL_cam_rotating_radius]call _setCirclePosition;
	LDL_ac130_plane setDir (LDL_cam_rotating_angle - 90);
};
	
if (typeName _input == "OBJECT") then
{
	LDL_ac130_plane = _input;
	
	//fly
	[LDL_ac130_plane]spawn
	{
		_plane = _this select 0;
		waitUntil{sleep 1;(!LDL_ac130_active)};
		_plane enableSimulation true;
		_vel = [sin(getDir LDL_ac130_plane)*200,cos(getDir _plane)*200,0];
		_plane setVelocity _vel;
	};

	_variables call LDL_setVariables;
	
	_pos = LDL_ac130_plane modelToWorld [_radius*-1,0,0];
	
	LDL_cam_rotating_center setPos [_pos select 0,_pos select 1,0];
	LDL_cam_rotating_height = getPosASL LDL_ac130_plane select 2; //TODO: take the height from the call argument
	LDL_cam_rotating_angle = [(getDir LDL_ac130_plane) + 90]call LDL_normalizeAngle;
	LDL_cam_dirh = [LDL_cam_rotating_angle-180]call LDL_normalizeAngle;
};

if(_sequence) then
{
	#include "ac130_rot_sequence.sqf"
};

LDL_ac130_plane engineOn true;

if(!_enablePhysics) then
{
	[]spawn 
	{
		sleep 3;
		LDL_ac130_plane enableSimulation false;
	};
};

LDL_flyMode = 1;

//Create the dialog
_dialog = createDialog "LDL_AC130Dialog";

//Create the cam
LDL_ac130_cam = []call LDL_createCam;

//Start all scripts
[]spawn LDL_ac130_rot_camera;
[]spawn LDL_ac130_rot_main;
[]spawn LDL_ac130_blink;
[]spawn LDL_ac130_troops;
[]spawn LDL_ac130_sound;
[]spawn LDL_ac130_rot_waypoints;

disableSerialization;
_display = (finddisplay  1000);

//Info Left
if(LDL_showFlir) then
{
	(_display displayctrl 1017) ctrlSetTextColor [1,0,0,1];
};

if(LDL_useNVG) then
{
	(_display displayctrl 1018) ctrlSetTextColor [1,0,0,1];
};

if(LDL_showBlink) then
{
	(_display displayctrl 1019) ctrlSetTextColor [1,0,0,1];
};

if(LDL_showTroops) then
{
	(_display displayctrl 1020) ctrlSetTextColor [1,0,0,1];
};

if(LDL_showWaypoints) then
{
	(_display displayctrl 1021) ctrlSetTextColor [1,0,0,1];
};